nsi.granulate.tests.testGranulateDOC

Package nsi :: Package granulate :: Package tests :: Module testGranulateDOC |
[hide private]
[frames] | no frames]

# Module testGranulateDOC

source code

Author: Ronaldo Amaral Santos <ronaldinho.as@gmail.com>

Classes | [hide private]
| TestGranulate

Variables | [hide private]
| filePath = ``'``/usr/lib/python2.4/site-packages/granulate-0.1dev-``...``
| filedata = ``'``\xd0\xcf\x11\xe0\xa1\xb1\x1a\xe1\x00\x00\x00\x00\x``...``

Variables Details | [hide private]

  ### filePath Value:
      '/usr/lib/python2.4/site-packages/granulate-0.1dev-py2.4.egg/nsi/granu
      late/tests/data/test.doc'

  ### filedata Value:
      '''\xd0\xcf\x11\xe0\xa1\xb1\x1a\xe1\x00\x00\x00\x00\x00\x00\x00\x00\x0
      0\x00\x00\x00\x00\x00\x00\x00>\x00\x03\x00\xfe\xff\t\x00\x06\x00\x00\x
      00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00r\x00\x00\x00\x00\x0
      0\x00\x00\x00\x10\x00\x00t\x00\x00\x00\x01\x00\x00\x00\xfe\xff\xff\xff
      \x00\x00\x00\x00q\x00\x00\x00\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\
      xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xf
      f\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\
      xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xff\xf
      ...